@@ -18,9 +18,9 @@ import com.google.gwt.user.client.ui.HTML;
 import com.google.gwt.user.client.ui.HasAlignment;
 import com.google.gwt.user.client.ui.RootPanel;
 import com.google.gwt.user.client.ui.VerticalPanel;
-@Deprecated
+
 public class CheckSession {
-	private final int MILLI_SECONDS = 55 * 1000; //(milli)seconds
+	private final int MILLI_SECONDS = 30 * 1000; //(milli)seconds
 
 	//for css and images
 	private static CheckSessionBundle images = GWT.create(CheckSessionBundle.class);
@@ -65,6 +65,16 @@ public class CheckSession {
 			singleton = new CheckSession();
 		return singleton;
 	}
+	
+
+	public static native boolean isSessionExpired() /*-{
+		var session_state = $wnd.Liferay.Session.get('sessionState');
+		var toReturn = (session_state == "expired");
+		console.log("check session_state = " + session_state + " session expired? " + toReturn);
+		return toReturn;
+	}-*/;	
+	
+	
 	/**
 	 * use this constructor if you want to get an event when session expires
 	 * @param eventBus GWT webapp instance of {@link HandlerManager}
@@ -85,47 +95,52 @@ public class CheckSession {
 		t = new Timer() {			
 			@Override
 			public void run() {
-				checkerService.checkSession(new AsyncCallback<SessionInfoBean>() {					
-					@Override
-					public void onSuccess(SessionInfoBean result) {
-						if (result != null) {
-
-							username = result.getUsername();
-							scope = result.getScope();
-							boolean userValid = ( username != null) ? true : false;
-							boolean scopeValid = (scope != null) ? true : false;
-
-							if (! (userValid && scopeValid) ) { //if session expired
-								mask(true);
-								stopPolling();
-								if (showSessionExpiredDialog) {
-									showLogoutDialog();									
-								} else {
-									if (eventBus == null)
-										throw new NullPointerException("Hey, it seems you chose to handle yourself session expiration "
-												+ "but also not to get informed about it (eventbus is null) what's the point then?");
-								}
-								if (eventBus != null) {
-									eventBus.fireEvent(new SessionTimeoutEvent(result));
-								}
-							}
-							else if (result.isDevMode()) {
-								GWT.log("Stopping polling because i think you're in development mode and not in a real portal");
-								stopPolling();
-							}
-						}	
-						else {
-							GWT.log("result null");
-							stopPolling();
-						}
-					}					
-					@Override
-					public void onFailure(Throwable caught) {
-						mask(true);
-						stopPolling();
-						showLogoutDialog();
-					}
-				});
+//				checkerService.checkSession(new AsyncCallback<SessionInfoBean>() {					
+//					@Override
+//					public void onSuccess(SessionInfoBean result) {
+//						if (result != null) {
+//
+//							username = result.getUsername();
+//							scope = result.getScope();
+//							boolean userValid = ( username != null) ? true : false;
+//							boolean scopeValid = (scope != null) ? true : false;
+//
+//							if (! (userValid && scopeValid) ) { //if session expired
+//								mask(true);
+//								stopPolling();
+//								if (showSessionExpiredDialog) {
+//									showLogoutDialog();									
+//								} else {
+//									if (eventBus == null)
+//										throw new NullPointerException("Hey, it seems you chose to handle yourself session expiration "
+//												+ "but also not to get informed about it (eventbus is null) what's the point then?");
+//								}
+//								if (eventBus != null) {
+//									eventBus.fireEvent(new SessionTimeoutEvent(result));
+//								}
+//							}
+//							else if (result.isDevMode()) {
+//								GWT.log("Stopping polling because i think you're in development mode and not in a real portal");
+//								stopPolling();
+//							}
+//						}	
+//						else {
+//							GWT.log("result null");
+//							stopPolling();
+//						}
+//					}					
+//					@Override
+//					public void onFailure(Throwable caught) {
+//						mask(true);
+//						stopPolling();
+//						showLogoutDialog();
+//					}
+//				});
+				if (isSessionExpired()) {
+					mask(true);
+					showLogoutDialog();
+				}
+					
 			}
 		};	
 	}
